==> QuickStart_Rhy-0.1.42.tar.gz: QuickStart_Rhy-0.1.42/README.md <==
# QuickStart

## Use QuickStart to simplify the operation in terminal!

| Command                    | Means                                                        |
| :------------------------- | :----------------------------------------------------------- |
| `qs -u <url> `           | open url using default browser                               |
| `qs -a <app> [files]` | open app or open file by app(for MacOS X)                    |
| `qs -f <file>`        | open file by default app                                     |
| `qs -trans [words]`        | translate the content of `[words]` or the content in clipboard |
| `qs -time`                 | view current time                                            |
| `qs -ftp`                  | start a simple ftp server                                    |
| `qs -top`                  | cpu and memory monitor                                       |
| `qs -rmbg <picture>`       | remove image background                                      |
| `qs -smms <picture/*.md>`  | upload images to sm.ms (or replace paths in markdown)        |
| `qs -ali_nas <-up/-dl file> [bucket]` | call aliyun nas api to upload or download file               |
| `qs -weather [address]`    | check weather (of address)                                   |
| `qs -dl [urls]`        | download file from url(in clipboard)                         |
| `qs -mktar <path>`       | create gzipped archive for path(dir/file)                    |
| `qs -untar <path>`       | extract path.tar.*                                           |
| `qs -mkzip <path>`       | make a zip for path(dir/file)                                |
| `qs -unzip <path>`       | unzip path.zip                                               |
| `qs -upload`               | upload your pypi library                                     |
| `qs -upgrade`              | update qs                                                    |

(By the way, if you are the one of China University Of Petroleum(Beijing), run `qs -i` to login school network)

## Some tools for Windows user to normally use qs

- almost have installed automatically by system on Linux/MacOS X

  [tar](http://gnuwin32.sourceforge.net/packages/gtar.htm)

  [zip](http://gnuwin32.sourceforge.net/packages/zip.htm)

  [unzip](http://gnuwin32.sourceforge.net/packages/unzip.htm)

==> QuickStart_Rhy-0.1.43.tar.gz: QuickStart_Rhy-0.1.43/README.md <==
# QuickStart

## Use QuickStart to simplify the operation in terminal!

| Command                    | Means                                                        |
| :------------------------- | :----------------------------------------------------------- |
| `qs -u <url> `           | open url using default browser                               |
| `qs -a <app> [files]` | open app or open file by app(for MacOS X)                    |
| `qs -f <file>`        | open file by default app                                     |
| `qs -trans [words]`        | translate the content of `[words]` or the content in clipboard |
| `qs -time`                 | view current time                                            |
| `qs -ftp`                  | start a simple ftp server                                    |
| `qs -top`                  | cpu and memory monitor                                       |
| `qs -rmbg <picture>`       | remove image background                                      |
| `qs -smms <picture/*.md>`  | upload images to sm.ms (or replace paths in markdown)        |
| `qs -ali_nas -help`        | get aliyun nas api help                                      |
| `qs -qiniu -help`          | get qiniu nas api help                                       |
| `qs -weather [address]`    | check weather (of address)                                   |
| `qs -dl [urls]`        | download file from url(in clipboard)                         |
| `qs -mktar <path>`       | create gzipped archive for path(dir/file)                    |
| `qs -untar <path>`       | extract path.tar.*                                           |
| `qs -mkzip <path>`       | make a zip for path(dir/file)                                |
| `qs -unzip <path>`       | unzip path.zip                                               |
| `qs -upload`               | upload your pypi library                                     |
| `qs -upgrade`              | update qs                                                    |

(By the way, if you are the one of China University Of Petroleum(Beijing), run `qs -i` to login school network)

## Some tools for Windows user to normally use qs

- almost have installed automatically by system on Linux/MacOS X

  [tar](http://gnuwin32.sourceforge.net/packages/gtar.htm)

  [zip](http://gnuwin32.sourceforge.net/packages/zip.htm)

  [unzip](http://gnuwin32.sourceforge.net/packages/unzip.htm)

~~~~
